#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-AvU9c2S4l8D2Oyqv5Aa9ed
key:                  haskell-language-server-2.3.0.0-AvU9c2S4l8D2Oyqv5Aa9ed
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  90e5695b3218f81180351a6634940e0f
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-AvU9c2S4l8D2Oyqv5Aa9ed
depends:
    aeson-pretty-0.8.11-BA3mR8CpiLMEdNcCSQLFvv
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf base-4.18.2.1
    base16-bytestring-1.0.2.0-JUk8AN14DnGL6jo9gy2A1N
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-FicrQGbdqQGEupCfHibC0e
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-Fl8012fesfY8JAHd1DYtXK
    githash-0.1.7.0-Fg8yc7ROXwtL5yKInFIZ
    hie-bios-0.12.0-LJvwJudLvBuLpaSm4UzpLl
    hiedb-0.4.3.0-KU0J8Xnn0al9iJMF7TDNCh
    hls-alternate-number-format-plugin-2.3.0.0-Eag6PiIswAzAc4nfVLlKHd
    hls-cabal-fmt-plugin-2.3.0.0-JvAZ2eH7m846CydH6NTymY
    hls-cabal-plugin-2.3.0.0-302i8rW2h9cAuh2G3WQT3E
    hls-call-hierarchy-plugin-2.3.0.0-BdiEvIqP094DwUahrnQGfg
    hls-change-type-signature-plugin-2.3.0.0-I6y4yRLUqyVJuKv1xyn2H1
    hls-class-plugin-2.3.0.0-KxkrkrLTV9W7lHOhry6OAJ
    hls-code-range-plugin-2.3.0.0-8Fph89jIQGYDoODVo11rU7
    hls-eval-plugin-2.3.0.0-FKgFYkwTgvBFZMLYfwuXsD
    hls-explicit-fixity-plugin-2.3.0.0-JPVuVzYGiRi4935Q5K5rEj
    hls-explicit-imports-plugin-2.3.0.0-A4ww8Nqo1tD2tUi8jlHkbT
    hls-explicit-record-fields-plugin-2.3.0.0-4Au6OiJXyo9DnJIJCj6Ez8
    hls-fourmolu-plugin-2.3.0.0-FY0BHOEmWUqLF5dqqGhFUv
    hls-gadt-plugin-2.3.0.0-AyEiLejJfBO2VAcEkLGrxU
    hls-graph-2.3.0.0-J4ReKBiXKa6ELhqG4l0L5h
    hls-hlint-plugin-2.3.0.0-6CpSt3dLOfsBQJcUMeLnON
    hls-module-name-plugin-2.3.0.0-GOe2dnbYVoZHC3zeH1eHuN
    hls-ormolu-plugin-2.3.0.0-IdPFVjWzcVDA4nJBDPXhGX
    hls-overloaded-record-dot-plugin-2.3.0.0-2PDeBHMg8HiIvI8CQ0OUe4
    hls-plugin-api-2.3.0.0-CqqJ1DVds9n4biAp5UxsaC
    hls-pragmas-plugin-2.3.0.0-5oGD41oPKeE1gt05jHg3Qn
    hls-qualify-imported-names-plugin-2.3.0.0-6s4e90q9pzyD9fc7u3abHA
    hls-refactor-plugin-2.3.0.0-AKU9CcjofBpJQDrbQ49r1t
    hls-rename-plugin-2.3.0.0-Kmfu27o0K7b8vaKUyVZ5eo
    hls-retrie-plugin-2.3.0.0-DqLiati3Qf9HYScJPsfi36
    hls-splice-plugin-2.3.0.0-JOKFM8nHuX48FpHQwTzMzU
    hls-stylish-haskell-plugin-2.3.0.0-DBVnpOyQJ42H0oKj1pkhSG
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
    optparse-applicative-0.18.1.0-47hFtTaenhPJTeGKwQSLW6
    optparse-simple-0.1.1.4-EBstS3Sjg9C5IWrADBA9wp
    prettyprinter-1.7.2-1DGqCnBpxP9HlPCcGuqpc1 process-1.6.19.0
    safe-exceptions-0.1.7.4-KsLBtnEzfQ1Kg6OJ9Y9PUU
    sqlite-simple-0.4.19.0-4Qmfk9YKC8OjwWkN2Ke3z text-2.0.2
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

